@@ -22,7 +22,7 @@ from django.db.models import (
 from pydantic.fields import ModelField, UndefinedType
 
 
-class FieldOptions(NamedTuple):
+class DjangoModelField(NamedTuple):
     name: str
     type: str
     extras: List[Dict[Any, Any]]
@@ -30,10 +30,15 @@ class FieldOptions(NamedTuple):
 
 class DjangoModel(NamedTuple):
     name: str
-    fields: List[FieldOptions]
+    fields: List[DjangoModelField]
 
 
 class DjangoCombustor:
+    """
+    This class contains methods in creating a DjangoModel tuple
+    to be used by jinja templates to render the Django models.
+    """
+
     valid_arguments: List[str] = [
         # general
         "null",
@@ -89,7 +94,8 @@ class DjangoCombustor:
         return model
 
     @classmethod
-    def _get_columns(cls, reactant) -> List[FieldOptions]:
+    def _get_columns(cls, reactant) -> List[DjangoModelField]:
+        """Builds the list of fields for a model."""
         column_list = []
         for name, value in reactant.__fields__.items():
             column_type = cls._map_type_to_orm_field(value)
@@ -97,7 +103,7 @@ class DjangoCombustor:
                 column_type, value
             )
 
-            column_info = FieldOptions(
+            column_info = DjangoModelField(
                 name=name, type=column_type_final.__name__, extras=extras_list
             )
             column_list.append(column_info)
@@ -144,17 +150,18 @@ class DjangoCombustor:
     @classmethod
     def _filter_field_arguments(cls, column_type: Any, value: Any) -> Sequence[Any]:
         """
-        This will filter out options that are not valid for the given Field type,
-        and set defaults for required arguments that are not specified by the reactant model.
+        This will filter out options that are not valid for Django model fields,
+        and set defaults for required arguments that are not explicitly set in the reactant model.
         """
 
+        # actual filtering of the arguments
         new_extra_options = {
             k: value.field_info.extra[k]
             for k in cls.valid_arguments
             if k in value.field_info.extra
         }
 
-        extras_list = []
+        extras_list = []  # this holds the arguments for the given field
 
         if not issubclass(type(value.field_info.default), UndefinedType):
             extras_list.append({"default": value.field_info.default})
